@@ -34,9 +34,9 @@ namespace KDevelop
  * From within a Declaration or DUContext, ENSURE_CAN_WRITE and ENSURE_CAN_READ should be used instead of these.
  */
 #if !defined(NDEBUG) && !defined(NO_DUCHAIN_LOCK_TESTING)
-#define ENSURE_CHAIN_READ_LOCKED Q_ASSERT(DUChain::lock()->currentThreadHasReadLock() || DUChain::lock()->currentThreadHasWriteLock());
-#define ENSURE_CHAIN_WRITE_LOCKED Q_ASSERT(DUChain::lock()->currentThreadHasWriteLock());
-#define ENSURE_CHAIN_NOT_LOCKED Q_ASSERT(!DUChain::lock()->currentThreadHasReadLock() && !DUChain::lock()->currentThreadHasWriteLock());
+#define ENSURE_CHAIN_READ_LOCKED Q_ASSERT(KDevelop::DUChain::lock()->currentThreadHasReadLock() || KDevelop::DUChain::lock()->currentThreadHasWriteLock());
+#define ENSURE_CHAIN_WRITE_LOCKED Q_ASSERT(KDevelop::DUChain::lock()->currentThreadHasWriteLock());
+#define ENSURE_CHAIN_NOT_LOCKED Q_ASSERT(!KDevelop::DUChain::lock()->currentThreadHasReadLock() && !KDevelop::DUChain::lock()->currentThreadHasWriteLock());
 #else
 #define ENSURE_CHAIN_READ_LOCKED
 #define ENSURE_CHAIN_WRITE_LOCKED
