@@ -42,7 +42,7 @@ class KDevDocumentViewPluginFactory: public KDevelop::IToolViewFactory
     public:
         KDevDocumentViewPluginFactory( KDevDocumentViewPlugin *plugin ): m_plugin( plugin )
         {}
-        virtual QWidget* create( QWidget *parent = 0 ) override
+        QWidget* create( QWidget *parent = 0 ) override
         {
             KDevDocumentView* view = new KDevDocumentView( m_plugin, parent );
             KDevelop::IDocumentController* docController = m_plugin->core()->documentController();
@@ -68,14 +68,14 @@ class KDevDocumentViewPluginFactory: public KDevelop::IToolViewFactory
                     view, &KDevDocumentView::documentUrlChanged );
             return view;
         }
-        virtual Qt::DockWidgetArea defaultPosition() override
+        Qt::DockWidgetArea defaultPosition() override
         {
             return Qt::LeftDockWidgetArea;
         }
 
-        virtual QString id() const override
+        QString id() const override
         {
-            return "org.kdevelop.DocumentsView";
+            return QStringLiteral("org.kdevelop.DocumentsView");
         }
 
     private:
@@ -84,7 +84,7 @@ class KDevDocumentViewPluginFactory: public KDevelop::IToolViewFactory
 
 
 KDevDocumentViewPlugin::KDevDocumentViewPlugin( QObject *parent, const QVariantList& args )
-        : KDevelop::IPlugin( "kdevdocumentview", parent )
+        : KDevelop::IPlugin( QStringLiteral( "kdevdocumentview" ), parent )
 {
     Q_UNUSED( args );
 
@@ -92,7 +92,7 @@ KDevDocumentViewPlugin::KDevDocumentViewPlugin( QObject *parent, const QVariantL
 
     core()->uiController()->addToolView( i18n("Documents"), factory );
 
-    setXMLFile( "kdevdocumentview.rc" );
+    setXMLFile( QStringLiteral( "kdevdocumentview.rc" ) );
 }
 
 KDevDocumentViewPlugin::~KDevDocumentViewPlugin()
