@@ -23,9 +23,6 @@
 
 #include <kdevcmodule.h>
 
-#include <kurl.h>
-#include <kstandarddirs.h>
-
 namespace Ui
 {
 class SettingsWidget;
