@@ -47,9 +47,9 @@ TemplateOptionsPage::TemplateOptionsPage(QWidget* parent, Qt::WindowFlags f)
 : QWidget(parent, f)
 , d(new TemplateOptionsPagePrivate)
 {
-    d->typeProperties.insert("String", "text");
-    d->typeProperties.insert("Int", "value");
-    d->typeProperties.insert("Bool", "checked");
+    d->typeProperties.insert(QStringLiteral("String"), "text");
+    d->typeProperties.insert(QStringLiteral("Int"), "value");
+    d->typeProperties.insert(QStringLiteral("Bool"), "checked");
 }
 
 TemplateOptionsPage::~TemplateOptionsPage()
@@ -75,14 +75,13 @@ void TemplateOptionsPage::load(const SourceFileTemplate& fileTemplate, TemplateR
         d->entries << it.value();
         foreach (const SourceFileTemplate::ConfigOption& entry, it.value())
         {
-            QLabel* label = new QLabel(entry.label, box);
             QWidget* control = 0;
             const QString type = entry.type;
-            if (type == "String")
+            if (type == QLatin1String("String"))
             {
                 control = new QLineEdit(entry.value.toString(), box);
             }
-            else if (type == "Int")
+            else if (type == QLatin1String("Int"))
             {
                 auto input = new QSpinBox(box);
                 input->setValue(entry.value.toInt());
@@ -96,11 +95,12 @@ void TemplateOptionsPage::load(const SourceFileTemplate& fileTemplate, TemplateR
                 }
                 control = input;
             }
-            else if (type == "Bool")
+            else if (type == QLatin1String("Bool"))
             {
-                bool checked = (QString::compare(entry.value.toString(), "true", Qt::CaseInsensitive) == 0);
-                QCheckBox* checkBox = new QCheckBox(entry.label, box);
+                bool checked = (QString::compare(entry.value.toString(), QStringLiteral("true"), Qt::CaseInsensitive) == 0);
+                QCheckBox* checkBox = new QCheckBox(box);
                 checkBox->setCheckState(checked ? Qt::Checked : Qt::Unchecked);
+                control = checkBox;
             }
             else
             {
@@ -108,6 +108,7 @@ void TemplateOptionsPage::load(const SourceFileTemplate& fileTemplate, TemplateR
             }
             if (control)
             {
+                QLabel* label = new QLabel(entry.label, box);
                 formLayout->addRow(label, control);
                 d->controls.insert(entry.name, control);
             }
