@@ -39,7 +39,7 @@ class TemplateSelectionPage : public QWidget
     Q_PROPERTY(QString selectedTemplate READ selectedTemplate)
 
 public:
-    explicit TemplateSelectionPage (TemplateClassAssistant* parent, Qt::WindowFlags f = 0);
+    explicit TemplateSelectionPage (TemplateClassAssistant* parent, Qt::WindowFlags f = nullptr);
     ~TemplateSelectionPage() override;
 
     /**
