@@ -21,12 +21,8 @@
 
 #include "projectfilterdebug.h"
 
+Q_LOGGING_CATEGORY(PLUGIN_PROJECTFILTER, "kdevplatform.plugins.projectfilter")
+
 namespace KDevelop {
 
-int projectFilterDebugArea()
-{
-    static int area = KDebug::registerArea("kdevprojectfilter");
-    return area;
-}
-
 }
