@@ -32,18 +32,9 @@ class Path;
 class KDEVPLATFORMPROJECT_EXPORT ProjectConfigSkeleton: public KConfigSkeleton
 {
     Q_OBJECT
+
 public:
-
-    /**
-     * Constructs a new skeleton, the skeleton will write to the developer
-     * configuration file, which is by default located in projectdir/.kdev4
-     * The defaults will be set from the project file, which is in the projectdir
-     *
-     * @param configname The absolute filename of the developer configuration file
-     */
-    explicit ProjectConfigSkeleton( const QString & configname );
-
-    virtual ~ProjectConfigSkeleton();
+    ~ProjectConfigSkeleton() override;
 
     void setDeveloperTempFile( const QString& );
     void setProjectTempFile( const QString& );
@@ -55,16 +46,20 @@ public:
 
     Path projectFile() const;
     Path developerFile() const;
-private:
+
+protected:
+    explicit ProjectConfigSkeleton( KSharedConfigPtr config );
     /**
-     * There's no way in KDE4 API to find out the file that the config object
-     * was created from, so we can't apply defaults when using this
-     * constructors. Thus I'm making this private, so we can find out when
-     * this constructor is used and see if we need to add appropriate API to
-     * kdelibs
+     * Constructs a new skeleton, the skeleton will write to the developer
+     * configuration file, which is by default located in projectdir/.kdev4
+     * The defaults will be set from the project file, which is in the projectdir
+     *
+     * @param configname The absolute filename of the developer configuration file
      */
-     explicit ProjectConfigSkeleton( KSharedConfigPtr config );
-     struct ProjectConfigSkeletonPrivate * const d;
+    explicit ProjectConfigSkeleton( const QString & configname );
+
+private:
+    struct ProjectConfigSkeletonPrivate * const d;
 };
 
 }
