@@ -223,7 +223,7 @@ struct DocumentControllerPrivate
         IDocument* buddy = 0)
     {
         Q_ASSERT(!inputUrl.isRelative());
-        Q_ASSERT(!inputUrl.fileName().isEmpty());
+        Q_ASSERT(!inputUrl.fileName().isEmpty() || !inputUrl.isLocalFile());
         QString _encoding = encoding;
 
         QUrl url = inputUrl;
@@ -725,15 +725,16 @@ void DocumentController::fileClose()
     }
 }
 
-void DocumentController::closeDocument( const QUrl &url )
+bool DocumentController::closeDocument( const QUrl &url )
 {
     if( !d->documents.contains(url) )
-        return;
+        return false;
 
     //this will remove all views and after the last view is removed, the
     //document will be self-destructed and removeDocument() slot will catch that
     //and clean up internal data structures
     d->documents[url]->close();
+    return true;
 }
 
 void DocumentController::notifyDocumentClosed(Sublime::Document* doc_)
@@ -765,7 +766,7 @@ IDocument * DocumentController::documentForUrl( const QUrl & dirtyUrl ) const
         return nullptr;
     }
     Q_ASSERT(!dirtyUrl.isRelative());
-    Q_ASSERT(!dirtyUrl.fileName().isEmpty());
+    Q_ASSERT(!dirtyUrl.fileName().isEmpty() || !dirtyUrl.isLocalFile());
     //Fix urls that might not be normalized
     return d->documents.value( dirtyUrl.adjusted( QUrl::NormalizePathSegments ), 0 );
 }
