@@ -25,6 +25,7 @@ Boston, MA 02110-1301, USA.
 #include <QPalette>
 #include <QSignalMapper>
 
+#include <KAboutData>
 #include <KActionCollection>
 #include <KActionMenu>
 #include <KColorScheme>
@@ -51,6 +52,7 @@ Boston, MA 02110-1301, USA.
 #include "mainwindow.h"
 #include "launchconfiguration.h"
 #include "launchconfigurationdialog.h"
+#include "unitylauncher.h"
 #include "debug.h"
 #include <interfaces/isession.h>
 
@@ -148,6 +150,8 @@ public:
     DebugMode* debugMode;
     ExecuteMode* executeMode;
     ProfileMode* profileMode;
+    UnityLauncher* unityLauncher;
+
     bool hasLaunchConfigType( const QString& typeId )
     {
         return launchConfigurationTypes.contains( typeId );
@@ -336,6 +340,9 @@ RunController::RunController(QObject *parent)
     d->debugMode = 0;
     d->profileMode = 0;
 
+    d->unityLauncher = new UnityLauncher(this);
+    d->unityLauncher->setLauncherId(KAboutData::applicationData().desktopFileName());
+
     if(!(Core::self()->setupFlags() & Core::NoUi)) {
         // Note that things like registerJob() do not work without the actions, it'll simply crash.
         setupActions();
@@ -605,6 +612,9 @@ void KDevelop::RunController::registerJob(KJob * job)
         connect( job, &KJob::finished, this, &RunController::finished );
         connect( job, &KJob::destroyed, this, &RunController::jobDestroyed );
 
+        // FIXME percent is a private signal and thus we cannot use new connext syntax
+        connect(job, SIGNAL(percent(KJob*,ulong)), this, SLOT(jobPercentChanged()));
+
         IRunController::registerJob(job);
 
         emit jobRegistered(job);
@@ -635,13 +645,27 @@ void KDevelop::RunController::checkState()
 {
     bool running = false;
 
-    foreach (KJob* job, d->jobs.keys()) {
+    int jobCount = 0;
+    int totalProgress = 0;
+
+    for (auto it = d->jobs.constBegin(), end = d->jobs.constEnd(); it != end; ++it) {
+        KJob *job = it.key();
+
         if (!job->isSuspended()) {
             running = true;
-            break;
+
+            ++jobCount;
+            totalProgress += job->percent();
         }
     }
 
+    d->unityLauncher->setProgressVisible(running);
+    if (jobCount > 0) {
+        d->unityLauncher->setProgress((totalProgress + 1) / jobCount);
+    } else {
+        d->unityLauncher->setProgress(0);
+    }
+
     if ( ( d->state != Running ? false : true ) == running ) {
         d->state = running ? Running : Idle;
         emit runStateChanged(d->state);
@@ -716,6 +740,11 @@ void RunController::jobDestroyed(QObject* job)
     }
 }
 
+void RunController::jobPercentChanged()
+{
+    checkState();
+}
+
 void KDevelop::RunController::suspended(KJob * job)
 {
     Q_UNUSED(job);
@@ -959,7 +988,7 @@ ContextMenuExtension RunController::contextMenuExtension ( Context* ctx )
         {
             ProjectBaseItem* itm = prjctx->items().at( 0 );
             int i = 0;
-            foreach( ILaunchMode* mode, d->launchModes.values() )
+            foreach( ILaunchMode* mode, d->launchModes )
             {
                 KActionMenu* menu = new KActionMenu( i18n("%1 As...", mode->name() ), this );
                 foreach( LaunchConfigurationType* type, launchConfigurationTypes() )
@@ -1009,7 +1038,6 @@ errorBrush( KColorScheme::View, KColorScheme::NegativeText )
 void RunDelegate::paint( QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index ) const
 {
     QStyleOptionViewItem opt = option;
-    QVariant status = index.data(Qt::UserRole+1);
 //     if( status.isValid() && status.canConvert<KDevelop::IRunProvider::OutputTypes>() )
 //     {
 //         IRunProvider::OutputTypes type = status.value<KDevelop::IRunProvider::OutputTypes>();
