@@ -67,9 +67,9 @@ TemplatePage::~TemplatePage()
 
 void TemplatePage::loadFromFile()
 {
-    QString filename = QFileDialog::getOpenFileName(this, QString(), QString(), m_provider->supportedMimeTypes().join(QStringLiteral(" ")));
-    if (!filename.isEmpty())
-    {
+    const QString filter = m_provider->supportedMimeTypes().join(QStringLiteral(";;"));
+    const QString filename = QFileDialog::getOpenFileName(this, QString(), QString(), filter);
+    if (!filename.isEmpty()) {
         m_provider->loadTemplate(filename);
     }
 
