@@ -23,9 +23,7 @@
 #include "ideallayout.h"
 #include "idealcontroller.h"
 
-#include "kdebug.h"
 #include <KConfigGroup>
-#include <KGlobal>
 #include <KConfig>
 
 using namespace Sublime;
@@ -251,4 +249,3 @@ int IdealButtonBarLayout::doHorizontalLayout(const QRect &rect, bool updateGeome
     return y + currentLineHeight + b;
 }
 
-#include "ideallayout.moc"
