@@ -32,7 +32,6 @@
 
 #include <vcs/vcsstatusinfo.h>
 
-
 namespace KDevelop
 {
 
@@ -78,6 +77,24 @@ static QIcon stateToIcon(KDevelop::VcsStatusInfo::State state)
     return QIcon::fromTheme(QStringLiteral("dialog-error"));
 }
 
+VcsFileChangesSortProxyModel::VcsFileChangesSortProxyModel(QObject* parent)
+    : QSortFilterProxyModel(parent)
+{
+}
+
+bool VcsFileChangesSortProxyModel::lessThan(const QModelIndex& source_left, const QModelIndex& source_right) const
+{
+    const auto leftStatus = source_left.data(VcsFileChangesModel::StateRole).value<VcsStatusInfo::State>();
+    const auto rightStatus = source_right.data(VcsFileChangesModel::StateRole).value<VcsStatusInfo::State>();
+    if (leftStatus != rightStatus) {
+        return leftStatus < rightStatus;
+    }
+
+    const QString leftPath = source_left.data(VcsFileChangesModel::UrlRole).toString();
+    const QString rightPath = source_right.data(VcsFileChangesModel::UrlRole).toString();
+    return QString::localeAwareCompare(leftPath, rightPath) < 0;
+}
+
 class VcsStatusInfoItem : public QStandardItem
 {
 public:
@@ -101,6 +118,8 @@ public:
                 return QVariant::fromValue(m_info);
             case VcsFileChangesModel::UrlRole:
                 return m_info.url();
+            case VcsFileChangesModel::StateRole:
+                return QVariant::fromValue(m_info.state());
         }
         return {};
     }
@@ -123,43 +142,47 @@ VcsFileChangesModel::VcsFileChangesModel(QObject *parent, bool allowSelection)
     setHeaderData(1, Qt::Horizontal, i18n("Status"));
 }
 
+VcsFileChangesModel::~VcsFileChangesModel()
+{
+}
+
 int VcsFileChangesModel::updateState(QStandardItem *parent, const KDevelop::VcsStatusInfo &status)
 {
     if(status.state()==VcsStatusInfo::ItemUnknown || status.state()==VcsStatusInfo::ItemUpToDate) {
         removeUrl(status.url());
         return -1;
     } else {
-        QStandardItem* it1 = fileItemForUrl(parent, status.url());
-        if(!it1) {
+        QStandardItem* item = fileItemForUrl(parent, status.url());
+        if(!item) {
             QString path = ICore::self()->projectController()->prettyFileName(status.url(), KDevelop::IProjectController::FormatPlain);
             QMimeType mime = status.url().isLocalFile()
                 ? QMimeDatabase().mimeTypeForFile(status.url().toLocalFile(), QMimeDatabase::MatchExtension)
                 : QMimeDatabase().mimeTypeForUrl(status.url());
             QIcon icon = QIcon::fromTheme(mime.iconName());
-            it1 = new QStandardItem(icon, path);
+            item = new QStandardItem(icon, path);
             auto itStatus = new VcsStatusInfoItem(status);
 
             if(d->allowSelection) {
-                it1->setCheckable(true);
-                it1->setCheckState(status.state() == VcsStatusInfo::ItemUnknown ? Qt::Unchecked : Qt::Checked);
+                item->setCheckable(true);
+                item->setCheckState(status.state() == VcsStatusInfo::ItemUnknown ? Qt::Unchecked : Qt::Checked);
             }
 
-            parent->appendRow({ it1, itStatus });
+            parent->appendRow({ item, itStatus });
         } else {
-            QStandardItem *parent = it1->parent();
+            QStandardItem *parent = item->parent();
             if(parent == 0)
                 parent = invisibleRootItem();
-            auto itStatus = static_cast<VcsStatusInfoItem*>(parent->child(it1->row(), 1));
-            itStatus->setStatus(status);
+            auto statusInfoItem = static_cast<VcsStatusInfoItem*>(parent->child(item->row(), 1));
+            statusInfoItem->setStatus(status);
         }
 
-        return it1->row();
+        return item->row();
     }
 }
 
 QVariant VcsFileChangesModel::data(const QModelIndex &index, int role) const
 {
-    if (role == UrlRole && index.column()==0) {
+    if (role >= VcsStatusInfoRole && index.column()==0) {
         return QStandardItemModel::data(index.sibling(index.row(), 1), role);
     }
     return QStandardItemModel::data(index, role);
@@ -168,30 +191,14 @@ QVariant VcsFileChangesModel::data(const QModelIndex &index, int role) const
 QStandardItem* VcsFileChangesModel::fileItemForUrl(QStandardItem* parent, const QUrl& url) const
 {
     for(int i=0, c=parent->rowCount(); i<c; i++) {
-        if(statusInfo(i, parent->index()).url()==url) {
+        QStandardItem* item = parent->child(i);
+        if(indexFromItem(item).data(UrlRole).toUrl() == url) {
             return parent->child(i);
         }
     }
     return 0;
 }
 
-QList<VcsStatusInfo> VcsFileChangesModel::checkedStatuses(QStandardItem *parent) const
-{
-    QList<VcsStatusInfo> ret;
-
-    if(!d->allowSelection)
-        return ret;
-
-    for(int i = 0, c = parent->rowCount(); i < c; i++) {
-        QStandardItem* item = parent->child(i);
-        if(item->checkState() == Qt::Checked) {
-            ret << statusInfo(i, parent->index());
-        }
-    }
-
-    return ret;
-}
-
 void VcsFileChangesModel::setAllChecked(bool checked)
 {
     if(!d->allowSelection)
@@ -206,30 +213,22 @@ void VcsFileChangesModel::setAllChecked(bool checked)
 QList<QUrl> VcsFileChangesModel::checkedUrls(QStandardItem *parent) const
 {
     QList<QUrl> ret;
-
     for(int i = 0, c = parent->rowCount(); i < c; i++) {
         QStandardItem* item = parent->child(i);
         if(!d->allowSelection || item->checkState() == Qt::Checked) {
-            ret << statusInfo(i, parent->index()).url();
+            ret << indexFromItem(item).data(UrlRole).toUrl();
         }
     }
-
     return ret;
 }
 
-VcsStatusInfo VcsFileChangesModel::statusInfo(int row, const QModelIndex &parent) const
-{
-    return index(row, 1, parent).data(VcsStatusInfoRole).value<VcsStatusInfo>();
-}
-
 QList<QUrl> VcsFileChangesModel::urls(QStandardItem *parent) const
 {
     QList<QUrl> ret;
-
     for(int i = 0, c = parent->rowCount(); i < c; i++) {
-        ret << statusInfo(i, parent->index()).url();
+        QStandardItem* item = parent->child(i);
+        ret << indexFromItem(item).data(UrlRole).toUrl();
     }
-
     return ret;
 }
 
@@ -242,7 +241,9 @@ void VcsFileChangesModel::checkUrls(QStandardItem *parent, const QList<QUrl>& ur
 
     for(int i = 0, c = parent->rowCount(); i < c; i++) {
         QStandardItem* item = parent->child(i);
-        item->setCheckState(urlSet.contains(statusInfo(i, parent->index()).url()) ? Qt::Checked : Qt::Unchecked);
+        item->setCheckState(urlSet.contains(indexFromItem(item).data(UrlRole).toUrl()) ?
+            Qt::Checked :
+            Qt::Unchecked);
     }
 }
 
@@ -256,35 +257,14 @@ bool VcsFileChangesModel::isCheckable() const
     return d->allowSelection;
 }
 
-QModelIndex VcsFileChangesModel::indexForUrl(const QUrl& url) const
-{
-    return indexForUrl(QModelIndex(), url);
-}
-
-QModelIndex VcsFileChangesModel::indexForUrl(const QModelIndex& parent, const QUrl& url) const
-{
-    for (int i=0, c=rowCount(parent); i<c; ++i) {
-        QModelIndex idx = index(i, 0, parent);
-        if (hasChildren(idx)) {
-            QModelIndex cidx = indexForUrl(idx, url);
-            if (cidx.isValid())
-                return cidx;
-        } else {
-            if (statusInfo(idx.row(), idx.parent()).url() == url) {
-                return idx;
-            }
-        }
-    }
-    return {};
-}
-
 bool VcsFileChangesModel::removeUrl(const QUrl& url)
 {
-    const QModelIndex idx = indexForUrl(url);
-    if(idx.isValid()) {
-        removeRow(idx.row(), idx.parent());
-    }
-    return idx.isValid();
+    const auto matches = match(index(0, 0), UrlRole, url, 1, Qt::MatchExactly);
+    if (matches.isEmpty())
+        return false;
+
+    const auto& idx = matches.first();
+    return removeRow(idx.row(), idx.parent());
 }
 
 }
