@@ -20,16 +20,15 @@
 
 #include "vcsitemeventmodel.h"
 
+#include <QIcon>
 #include <QModelIndex>
 #include <QVariant>
 #include <QList>
+#include <QUrl>
+#include <QMimeType>
+#include <QMimeDatabase>
 
-#include <klocale.h>
-#include <KMimeType>
-#include <KIcon>
-
-#include <tests/modeltest.h>
-#include <QDebug>
+#include <KLocalizedString>
 
 #include "../vcsrevision.h"
 #include "../vcsevent.h"
@@ -50,10 +49,11 @@ void VcsItemEventModel::addItemEvents( const QList<KDevelop::VcsItemEvent>& list
 {
     if(rowCount()==0)
         setColumnCount(2);
-    
+
     bool copySource = false;
+    QMimeDatabase mimeDataBase;
     foreach(const KDevelop::VcsItemEvent& ev, list) {
-        
+
         KDevelop::VcsItemEvent::Actions act = ev.actions();
         QStringList actionStrings;
         if( act & KDevelop::VcsItemEvent::Added )
@@ -66,9 +66,12 @@ void VcsItemEventModel::addItemEvents( const QList<KDevelop::VcsItemEvent>& list
             actionStrings << i18n("Copied");
         else if( act & KDevelop::VcsItemEvent::Replaced )
             actionStrings << i18n("Replaced");
-        KMimeType::Ptr mime = KMimeType::findByUrl( ev.repositoryLocation(), 0, false, true );
+        QUrl repoUrl = QUrl::fromLocalFile(ev.repositoryLocation());
+        QMimeType mime = repoUrl.isLocalFile()
+                ? mimeDataBase.mimeTypeForFile(repoUrl.toLocalFile(), QMimeDatabase::MatchExtension)
+                : mimeDataBase.mimeTypeForUrl(repoUrl);
         QList<QStandardItem*> rowItems = QList<QStandardItem*>()
-            << new QStandardItem(KIcon(mime->iconName()), ev.repositoryLocation())
+            << new QStandardItem(QIcon::fromTheme(mime.iconName()), ev.repositoryLocation())
             << new QStandardItem(actionStrings.join(i18nc("separes an action list", ", ")));
         QString loc = ev.repositoryCopySourceLocation();
         if(!loc.isEmpty()) { //according to the documentation, those are optional. don't force them on the UI
@@ -79,7 +82,7 @@ void VcsItemEventModel::addItemEvents( const QList<KDevelop::VcsItemEvent>& list
             }
             copySource = true;
         }
-        
+
         rowItems.first()->setData(qVariantFromValue(ev));
         appendRow(rowItems);
     }
@@ -109,4 +112,3 @@ KDevelop::VcsItemEvent VcsItemEventModel::itemEventForIndex( const QModelIndex&
 
 }
 
-#include "vcsitemeventmodel.moc"
